Type: Package
Package: qtl2pleio
Title: Testing Pleiotropy in Multiparental Populations
Version: 1.4.4
Authors@R: 
    person(given = "Frederick J",
           family = "Boehm",
           role = c("aut", "cre"),
           email = "frederick.boehm@gmail.com",
           comment = c(ORCID = "0000-0002-1644-5931"))
Description: We implement an
    adaptation of Jiang & Zeng's (1995) <doi:10.1093/genetics/140.3.1111> likelihood ratio test for testing
    the null hypothesis of pleiotropy against the alternative hypothesis,
    two separate quantitative trait loci. The test differs from that in Jiang & Zeng (1995)
    and that in Tian et al. (2016) <doi:10.1534/genetics.115.183624> in
    that our test accommodates multiparental populations.
License: MIT + file LICENSE
URL: https://github.com/fboehm/qtl2pleio
BugReports: https://github.com/fboehm/qtl2pleio/issues
Depends: R (>= 3.2)
Imports: dplyr, gemma2, ggplot2, magrittr, MASS, Rcpp, rlang, tibble,
        parallel
Suggests: covr, mvtnorm, knitr, rmarkdown, testthat, broman, devtools,
        qtl2, parallelly
LinkingTo: Rcpp, RcppEigen
Encoding: UTF-8
Language: en-US
NeedsCompilation: yes
RoxygenNote: 7.3.3
Packaged: 2026-04-25 19:40:25 UTC; fred
Author: Frederick J Boehm [aut, cre] (ORCID:
    <https://orcid.org/0000-0002-1644-5931>)
Maintainer: Frederick J Boehm <frederick.boehm@gmail.com>
Repository: CRAN
Date/Publication: 2026-04-25 23:30:02 UTC
Built: R 4.5.2; aarch64-apple-darwin20; 2026-04-26 23:59:19 UTC; unix
Archs: qtl2pleio.so.dSYM
