# Generated by roxygen2: do not edit by hand

export("%>%")
export(add_pmap)
export(boot_pvl)
export(calc_Bhat)
export(calc_Sigma)
export(calc_covs)
export(calc_lrt_tib)
export(calc_profile_lods)
export(check_identical)
export(check_missingness)
export(convert_to_scan1_output)
export(find_pleio_peak_tib)
export(fit1_pvl)
export(get_effects)
export(make_id2keep)
export(plot_pvl)
export(prep_X_list)
export(prep_mytab)
export(rcpp_calc_Bhat)
export(rcpp_calc_Bhat2)
export(rcpp_log_dmvnorm2)
export(scan_multi_onechr)
export(scan_multi_oneqtl)
export(scan_multi_oneqtl_perm)
export(scan_pvl)
export(sim1)
export(subset_input)
export(subset_kinship)
importFrom(Rcpp,sourceCpp)
importFrom(magrittr,"%>%")
importFrom(rlang,.data)
importFrom(stats,complete.cases)
importFrom(stats,profile)
importFrom(stats,var)
useDynLib(qtl2pleio, .registration = TRUE)
